"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class PremiumMarketingComponentProperties(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _ButtonAction:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ButtonActionEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[PremiumMarketingComponentProperties._ButtonAction.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        BUTTON_ACTION_UNSPECIFIED: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 0
        BUTTON_ACTION_OPEN_MARKETING_PAGE: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 1
        BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 2
        BUTTON_ACTION_OPEN_TIER_1_PAYMENT_MODAL: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 3
        BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL_CUSTOM_CONFIRMATION_FOOTER: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 4
        BUTTON_ACTION_OPEN_PLAN_SELECTION_MODAL: PremiumMarketingComponentProperties._ButtonAction.ValueType  # 5

    class ButtonAction(_ButtonAction, metaclass=_ButtonActionEnumTypeWrapper): ...
    BUTTON_ACTION_UNSPECIFIED: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 0
    BUTTON_ACTION_OPEN_MARKETING_PAGE: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 1
    BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 2
    BUTTON_ACTION_OPEN_TIER_1_PAYMENT_MODAL: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 3
    BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL_CUSTOM_CONFIRMATION_FOOTER: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 4
    BUTTON_ACTION_OPEN_PLAN_SELECTION_MODAL: PremiumMarketingComponentProperties.ButtonAction.ValueType  # 5

    @_typing.final
    class FeatureCard(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        PILL_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        IMAGE_LINK_FIELD_NUMBER: _builtins.int
        IMAGE_LINK_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        pill: _builtins.str
        body: _builtins.str
        image_link: _builtins.str
        image_link_light_theme: _builtins.str
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            pill: _builtins.str = ...,
            body: _builtins.str = ...,
            image_link: _builtins.str = ...,
            image_link_light_theme: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["body", b"body", "header", b"header", "image_link", b"image_link", "image_link_light_theme", b"image_link_light_theme", "pill", b"pill"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SubscriptionButton(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COPY_FIELD_NUMBER: _builtins.int
        BUTTON_ACTION_FIELD_NUMBER: _builtins.int
        copy: _builtins.str
        button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType
        def __init__(
            self,
            *,
            copy: _builtins.str = ...,
            button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["button_action", b"button_action", "copy", b"copy"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class Subtitle(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LINK_FIELD_NUMBER: _builtins.int
        LOCALE_FIELD_NUMBER: _builtins.int
        IS_DEFAULT_FIELD_NUMBER: _builtins.int
        link: _builtins.str
        locale: _builtins.str
        is_default: _builtins.bool
        def __init__(
            self,
            *,
            link: _builtins.str = ...,
            locale: _builtins.str = ...,
            is_default: _builtins.bool = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["is_default", b"is_default", "link", b"link", "locale", b"locale"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class Variant1Storage(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class HeroArtLocalizedVideoLinksDarkThemeEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            value: _builtins.str
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: _builtins.str = ...,
            ) -> None: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        @_typing.final
        class HeroArtLocalizedVideoLinksLightThemeEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            value: _builtins.str
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: _builtins.str = ...,
            ) -> None: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        @_typing.final
        class HeroArtVideoSubtitleLinksEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.str
            value: _builtins.str
            def __init__(
                self,
                *,
                key: _builtins.str = ...,
                value: _builtins.str = ...,
            ) -> None: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        HERO_ART_LOCALIZED_VIDEO_LINKS_DARK_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_LOCALIZED_VIDEO_LINKS_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_VIDEO_SUBTITLE_LINKS_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def hero_art_localized_video_links_dark_theme(self) -> _containers.ScalarMap[_builtins.str, _builtins.str]: ...
        @_builtins.property
        def hero_art_localized_video_links_light_theme(self) -> _containers.ScalarMap[_builtins.str, _builtins.str]: ...
        @_builtins.property
        def hero_art_video_subtitle_links(self) -> _containers.ScalarMap[_builtins.str, _builtins.str]: ...
        def __init__(
            self,
            *,
            hero_art_localized_video_links_dark_theme: _abc.Mapping[_builtins.str, _builtins.str] | None = ...,
            hero_art_localized_video_links_light_theme: _abc.Mapping[_builtins.str, _builtins.str] | None = ...,
            hero_art_video_subtitle_links: _abc.Mapping[_builtins.str, _builtins.str] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["hero_art_localized_video_links_dark_theme", b"hero_art_localized_video_links_dark_theme", "hero_art_localized_video_links_light_theme", b"hero_art_localized_video_links_light_theme", "hero_art_video_subtitle_links", b"hero_art_video_subtitle_links"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class AnnouncementModalVariant1Properties(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        SUBHEADER_FIELD_NUMBER: _builtins.int
        VIDEO_LINK_FIELD_NUMBER: _builtins.int
        HELP_ARTICLE_ID_FIELD_NUMBER: _builtins.int
        FEATURE_CARDS_FIELD_NUMBER: _builtins.int
        BUTTON_FIELD_NUMBER: _builtins.int
        DISMISS_KEY_FIELD_NUMBER: _builtins.int
        HERO_ART_VIDEO_LINK_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_IMAGE_LINK_DARK_THEME_FIELD_NUMBER: _builtins.int
        HERO_ART_IMAGE_LINK_LIGHT_THEME_FIELD_NUMBER: _builtins.int
        MODAL_TOP_PILL_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        HERO_ART_VIDEO_SUBTITLES_FIELD_NUMBER: _builtins.int
        STORAGE_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        subheader: _builtins.str
        video_link: _builtins.str
        help_article_id: _builtins.str
        dismiss_key: _builtins.str
        hero_art_video_link_light_theme: _builtins.str
        hero_art_image_link_dark_theme: _builtins.str
        hero_art_image_link_light_theme: _builtins.str
        modal_top_pill: _builtins.str
        body: _builtins.str
        @_builtins.property
        def feature_cards(self) -> _containers.RepeatedCompositeFieldContainer[Global___PremiumMarketingComponentProperties.FeatureCard]: ...
        @_builtins.property
        def button(self) -> Global___PremiumMarketingComponentProperties.SubscriptionButton: ...
        @_builtins.property
        def hero_art_video_subtitles(self) -> _containers.RepeatedCompositeFieldContainer[Global___PremiumMarketingComponentProperties.Subtitle]: ...
        @_builtins.property
        def storage(self) -> Global___PremiumMarketingComponentProperties.Variant1Storage: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            subheader: _builtins.str = ...,
            video_link: _builtins.str = ...,
            help_article_id: _builtins.str = ...,
            feature_cards: _abc.Iterable[Global___PremiumMarketingComponentProperties.FeatureCard] | None = ...,
            button: Global___PremiumMarketingComponentProperties.SubscriptionButton | None = ...,
            dismiss_key: _builtins.str = ...,
            hero_art_video_link_light_theme: _builtins.str = ...,
            hero_art_image_link_dark_theme: _builtins.str = ...,
            hero_art_image_link_light_theme: _builtins.str = ...,
            modal_top_pill: _builtins.str = ...,
            body: _builtins.str = ...,
            hero_art_video_subtitles: _abc.Iterable[Global___PremiumMarketingComponentProperties.Subtitle] | None = ...,
            storage: Global___PremiumMarketingComponentProperties.Variant1Storage | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "_storage", b"_storage", "button", b"button", "storage", b"storage"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "_storage", b"_storage", "body", b"body", "button", b"button", "dismiss_key", b"dismiss_key", "feature_cards", b"feature_cards", "header", b"header", "help_article_id", b"help_article_id", "hero_art_image_link_dark_theme", b"hero_art_image_link_dark_theme", "hero_art_image_link_light_theme", b"hero_art_image_link_light_theme", "hero_art_video_link_light_theme", b"hero_art_video_link_light_theme", "hero_art_video_subtitles", b"hero_art_video_subtitles", "modal_top_pill", b"modal_top_pill", "storage", b"storage", "subheader", b"subheader", "video_link", b"video_link"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__button: _TypeAlias = _typing.Literal["button"]  # noqa: Y015
        _WhichOneofArgType__button: _TypeAlias = _typing.Literal["_button", b"_button"]  # noqa: Y015
        _WhichOneofReturnType__storage: _TypeAlias = _typing.Literal["storage"]  # noqa: Y015
        _WhichOneofArgType__storage: _TypeAlias = _typing.Literal["_storage", b"_storage"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__button) -> _WhichOneofReturnType__button | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__storage) -> _WhichOneofReturnType__storage | None: ...

    @_typing.final
    class PremiumTab(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BADGE_LABEL_FIELD_NUMBER: _builtins.int
        ACKNOWLEDGED_BADGE_LABEL_FIELD_NUMBER: _builtins.int
        badge_label: _builtins.str
        acknowledged_badge_label: _builtins.str
        def __init__(
            self,
            *,
            badge_label: _builtins.str = ...,
            acknowledged_badge_label: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["acknowledged_badge_label", b"acknowledged_badge_label", "badge_label", b"badge_label"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class MarketingPageBannerButton(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COPY_FIELD_NUMBER: _builtins.int
        BUTTON_ACTION_FIELD_NUMBER: _builtins.int
        copy: _builtins.str
        button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType
        def __init__(
            self,
            *,
            copy: _builtins.str = ...,
            button_action: Global___PremiumMarketingComponentProperties.ButtonAction.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["button_action", b"button_action", "copy", b"copy"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class MarketingPageBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        HELP_ARTICLE_ID_FIELD_NUMBER: _builtins.int
        BUTTON_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        help_article_id: _builtins.str
        @_builtins.property
        def button(self) -> Global___PremiumMarketingComponentProperties.MarketingPageBannerButton: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            help_article_id: _builtins.str = ...,
            button: Global___PremiumMarketingComponentProperties.MarketingPageBannerButton | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "button", b"button"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "asset_url", b"asset_url", "body", b"body", "button", b"button", "header", b"header", "help_article_id", b"help_article_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__button: _TypeAlias = _typing.Literal["button"]  # noqa: Y015
        _WhichOneofArgType__button: _TypeAlias = _typing.Literal["_button", b"_button"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__button) -> _WhichOneofReturnType__button | None: ...

    @_typing.final
    class PaymentModalBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["asset_url", b"asset_url", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class CTAButton(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COPY_FIELD_NUMBER: _builtins.int
        copy: _builtins.str
        def __init__(
            self,
            *,
            copy: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["copy", b"copy"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class MobileBottomSheet(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        HELP_ARTICLE_ID_FIELD_NUMBER: _builtins.int
        BUTTON_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        help_article_id: _builtins.str
        @_builtins.property
        def button(self) -> Global___PremiumMarketingComponentProperties.CTAButton: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            help_article_id: _builtins.str = ...,
            button: Global___PremiumMarketingComponentProperties.CTAButton | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "button", b"button"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_button", b"_button", "asset_url", b"asset_url", "body", b"body", "button", b"button", "header", b"header", "help_article_id", b"help_article_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__button: _TypeAlias = _typing.Literal["button"]  # noqa: Y015
        _WhichOneofArgType__button: _TypeAlias = _typing.Literal["_button", b"_button"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__button) -> _WhichOneofReturnType__button | None: ...

    @_typing.final
    class Gradient(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COLORS_FIELD_NUMBER: _builtins.int
        ANGLE_FIELD_NUMBER: _builtins.int
        angle: _builtins.float
        @_builtins.property
        def colors(self) -> _containers.RepeatedScalarFieldContainer[_builtins.str]: ...
        def __init__(
            self,
            *,
            colors: _abc.Iterable[_builtins.str] | None = ...,
            angle: _builtins.float = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["angle", b"angle", "colors", b"colors"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GiftIcon(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BOX_ANIMATION_URL_FIELD_NUMBER: _builtins.int
        TRINKET_ANIMATION_URL_FIELD_NUMBER: _builtins.int
        TRINKET_GLOW_ANIMATION_URL_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        box_animation_url: _builtins.str
        trinket_animation_url: _builtins.str
        trinket_glow_animation_url: _builtins.str
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        def __init__(
            self,
            *,
            box_animation_url: _builtins.str = ...,
            trinket_animation_url: _builtins.str = ...,
            trinket_glow_animation_url: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_gradient", b"_gradient", "gradient", b"gradient"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_gradient", b"_gradient", "box_animation_url", b"box_animation_url", "gradient", b"gradient", "trinket_animation_url", b"trinket_animation_url", "trinket_glow_animation_url", b"trinket_glow_animation_url"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...

    @_typing.final
    class ThemeAwareAsset(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LIGHT_URL_FIELD_NUMBER: _builtins.int
        DARK_URL_FIELD_NUMBER: _builtins.int
        LIGHT_STATIC_URL_FIELD_NUMBER: _builtins.int
        DARK_STATIC_URL_FIELD_NUMBER: _builtins.int
        light_url: _builtins.str
        dark_url: _builtins.str
        light_static_url: _builtins.str
        dark_static_url: _builtins.str
        def __init__(
            self,
            *,
            light_url: _builtins.str = ...,
            dark_url: _builtins.str = ...,
            light_static_url: _builtins.str = ...,
            dark_static_url: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["dark_static_url", b"dark_static_url", "dark_url", b"dark_url", "light_static_url", b"light_static_url", "light_url", b"light_url"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GiftIconCoachmark(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        ASSET_URL_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        body: _builtins.str
        asset_url: _builtins.str
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            asset_url: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset", "asset_url", b"asset_url", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...

    @_typing.final
    class GiftPlanSelectionCardBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        DESKTOP_BODY_FIELD_NUMBER: _builtins.int
        MOBILE_BODY_FIELD_NUMBER: _builtins.int
        AVATAR_ASSET_FIELD_NUMBER: _builtins.int
        BANNER_ASSET_URL_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_URL_FIELD_NUMBER: _builtins.int
        CARD_ASSET_URL_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        BANNER_ASSET_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        CARD_ASSET_FIELD_NUMBER: _builtins.int
        MOBILE_BANNER_ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        desktop_body: _builtins.str
        mobile_body: _builtins.str
        banner_asset_url: _builtins.str
        background_asset_url: _builtins.str
        card_asset_url: _builtins.str
        @_builtins.property
        def avatar_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        @_builtins.property
        def banner_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def card_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def mobile_banner_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            desktop_body: _builtins.str = ...,
            mobile_body: _builtins.str = ...,
            avatar_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            banner_asset_url: _builtins.str = ...,
            background_asset_url: _builtins.str = ...,
            card_asset_url: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
            banner_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            card_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            mobile_banner_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_avatar_asset", b"_avatar_asset", "_background_asset", b"_background_asset", "_banner_asset", b"_banner_asset", "_card_asset", b"_card_asset", "_gradient", b"_gradient", "_mobile_banner_asset", b"_mobile_banner_asset", "avatar_asset", b"avatar_asset", "background_asset", b"background_asset", "banner_asset", b"banner_asset", "card_asset", b"card_asset", "gradient", b"gradient", "mobile_banner_asset", b"mobile_banner_asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_avatar_asset", b"_avatar_asset", "_background_asset", b"_background_asset", "_banner_asset", b"_banner_asset", "_card_asset", b"_card_asset", "_gradient", b"_gradient", "_mobile_banner_asset", b"_mobile_banner_asset", "avatar_asset", b"avatar_asset", "background_asset", b"background_asset", "background_asset_url", b"background_asset_url", "banner_asset", b"banner_asset", "banner_asset_url", b"banner_asset_url", "card_asset", b"card_asset", "card_asset_url", b"card_asset_url", "desktop_body", b"desktop_body", "gradient", b"gradient", "header", b"header", "mobile_banner_asset", b"mobile_banner_asset", "mobile_body", b"mobile_body"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__avatar_asset: _TypeAlias = _typing.Literal["avatar_asset"]  # noqa: Y015
        _WhichOneofArgType__avatar_asset: _TypeAlias = _typing.Literal["_avatar_asset", b"_avatar_asset"]  # noqa: Y015
        _WhichOneofReturnType__background_asset: _TypeAlias = _typing.Literal["background_asset"]  # noqa: Y015
        _WhichOneofArgType__background_asset: _TypeAlias = _typing.Literal["_background_asset", b"_background_asset"]  # noqa: Y015
        _WhichOneofReturnType__banner_asset: _TypeAlias = _typing.Literal["banner_asset"]  # noqa: Y015
        _WhichOneofArgType__banner_asset: _TypeAlias = _typing.Literal["_banner_asset", b"_banner_asset"]  # noqa: Y015
        _WhichOneofReturnType__card_asset: _TypeAlias = _typing.Literal["card_asset"]  # noqa: Y015
        _WhichOneofArgType__card_asset: _TypeAlias = _typing.Literal["_card_asset", b"_card_asset"]  # noqa: Y015
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        _WhichOneofReturnType__mobile_banner_asset: _TypeAlias = _typing.Literal["mobile_banner_asset"]  # noqa: Y015
        _WhichOneofArgType__mobile_banner_asset: _TypeAlias = _typing.Literal["_mobile_banner_asset", b"_mobile_banner_asset"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__avatar_asset) -> _WhichOneofReturnType__avatar_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__background_asset) -> _WhichOneofReturnType__background_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__banner_asset) -> _WhichOneofReturnType__banner_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__card_asset) -> _WhichOneofReturnType__card_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__mobile_banner_asset) -> _WhichOneofReturnType__mobile_banner_asset | None: ...

    @_typing.final
    class GiftCustomizationBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        DESKTOP_BODY_FIELD_NUMBER: _builtins.int
        MOBILE_BODY_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_URL_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        MOBILE_BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        desktop_body: _builtins.str
        mobile_body: _builtins.str
        background_asset_url: _builtins.str
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def mobile_background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            desktop_body: _builtins.str = ...,
            mobile_body: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
            background_asset_url: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            mobile_background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "_mobile_background_asset", b"_mobile_background_asset", "asset", b"asset", "background_asset", b"background_asset", "gradient", b"gradient", "mobile_background_asset", b"mobile_background_asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "_mobile_background_asset", b"_mobile_background_asset", "asset", b"asset", "asset_url", b"asset_url", "background_asset", b"background_asset", "background_asset_url", b"background_asset_url", "desktop_body", b"desktop_body", "gradient", b"gradient", "mobile_background_asset", b"mobile_background_asset", "mobile_body", b"mobile_body"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        _WhichOneofReturnType__background_asset: _TypeAlias = _typing.Literal["background_asset"]  # noqa: Y015
        _WhichOneofArgType__background_asset: _TypeAlias = _typing.Literal["_background_asset", b"_background_asset"]  # noqa: Y015
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        _WhichOneofReturnType__mobile_background_asset: _TypeAlias = _typing.Literal["mobile_background_asset"]  # noqa: Y015
        _WhichOneofArgType__mobile_background_asset: _TypeAlias = _typing.Literal["_mobile_background_asset", b"_mobile_background_asset"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__background_asset) -> _WhichOneofReturnType__background_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__mobile_background_asset) -> _WhichOneofReturnType__mobile_background_asset | None: ...

    @_typing.final
    class BillingSettingsNitroGiftBanner(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_URL_FIELD_NUMBER: _builtins.int
        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_URL_FIELD_NUMBER: _builtins.int
        GRADIENT_FIELD_NUMBER: _builtins.int
        TEXT_COLOR_FIELD_NUMBER: _builtins.int
        ADDITIONAL_TERMS_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        BACKGROUND_ASSET_FIELD_NUMBER: _builtins.int
        asset_url: _builtins.str
        header: _builtins.str
        body: _builtins.str
        background_asset_url: _builtins.str
        text_color: _builtins.str
        additional_terms: _builtins.str
        @_builtins.property
        def gradient(self) -> Global___PremiumMarketingComponentProperties.Gradient: ...
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        @_builtins.property
        def background_asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            asset_url: _builtins.str = ...,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            background_asset_url: _builtins.str = ...,
            gradient: Global___PremiumMarketingComponentProperties.Gradient | None = ...,
            text_color: _builtins.str = ...,
            additional_terms: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
            background_asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "asset", b"asset", "background_asset", b"background_asset", "gradient", b"gradient"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "_background_asset", b"_background_asset", "_gradient", b"_gradient", "additional_terms", b"additional_terms", "asset", b"asset", "asset_url", b"asset_url", "background_asset", b"background_asset", "background_asset_url", b"background_asset_url", "body", b"body", "gradient", b"gradient", "header", b"header", "text_color", b"text_color"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        _WhichOneofReturnType__background_asset: _TypeAlias = _typing.Literal["background_asset"]  # noqa: Y015
        _WhichOneofArgType__background_asset: _TypeAlias = _typing.Literal["_background_asset", b"_background_asset"]  # noqa: Y015
        _WhichOneofReturnType__gradient: _TypeAlias = _typing.Literal["gradient"]  # noqa: Y015
        _WhichOneofArgType__gradient: _TypeAlias = _typing.Literal["_gradient", b"_gradient"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__background_asset) -> _WhichOneofReturnType__background_asset | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__gradient) -> _WhichOneofReturnType__gradient | None: ...

    @_typing.final
    class GiftReminderNagbar(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BODY_FIELD_NUMBER: _builtins.int
        body: _builtins.str
        def __init__(
            self,
            *,
            body: _builtins.str = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["body", b"body"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class GiftReminderCoachmark(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        ASSET_URL_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        body: _builtins.str
        asset_url: _builtins.str
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            asset_url: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset", "asset_url", b"asset_url", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...

    @_typing.final
    class PremiumTabTooltip(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HEADER_FIELD_NUMBER: _builtins.int
        BODY_FIELD_NUMBER: _builtins.int
        ASSET_FIELD_NUMBER: _builtins.int
        header: _builtins.str
        body: _builtins.str
        @_builtins.property
        def asset(self) -> Global___PremiumMarketingComponentProperties.ThemeAwareAsset: ...
        def __init__(
            self,
            *,
            header: _builtins.str = ...,
            body: _builtins.str = ...,
            asset: Global___PremiumMarketingComponentProperties.ThemeAwareAsset | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_asset", b"_asset", "asset", b"asset", "body", b"body", "header", b"header"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__asset: _TypeAlias = _typing.Literal["asset"]  # noqa: Y015
        _WhichOneofArgType__asset: _TypeAlias = _typing.Literal["_asset", b"_asset"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__asset) -> _WhichOneofReturnType__asset | None: ...

    CONTENT_IDENTIFIER_FIELD_NUMBER: _builtins.int
    PLACEHOLDER_FIELD_NUMBER: _builtins.int
    ANNOUNCEMENT_MODAL_VARIANT_1_FIELD_NUMBER: _builtins.int
    PREMIUM_TAB_FIELD_NUMBER: _builtins.int
    MARKETING_PAGE_BANNER_FIELD_NUMBER: _builtins.int
    PAYMENT_MODAL_BANNER_FIELD_NUMBER: _builtins.int
    MOBILE_BOTTOM_SHEET_FIELD_NUMBER: _builtins.int
    GIFT_ICON_FIELD_NUMBER: _builtins.int
    GIFT_ICON_COACHMARK_FIELD_NUMBER: _builtins.int
    GIFT_PLAN_SELECTION_CARD_BANNER_FIELD_NUMBER: _builtins.int
    GIFT_CUSTOMIZATION_BANNER_FIELD_NUMBER: _builtins.int
    BILLING_SETTINGS_NITRO_GIFT_BANNER_FIELD_NUMBER: _builtins.int
    GIFT_REMINDER_NAGBAR_FIELD_NUMBER: _builtins.int
    GIFT_REMINDER_COACHMARK_FIELD_NUMBER: _builtins.int
    PREMIUM_TAB_TOOLTIP_FIELD_NUMBER: _builtins.int
    content_identifier: _builtins.str
    placeholder: _builtins.str
    @_builtins.property
    def announcement_modal_variant_1(self) -> Global___PremiumMarketingComponentProperties.AnnouncementModalVariant1Properties: ...
    @_builtins.property
    def premium_tab(self) -> Global___PremiumMarketingComponentProperties.PremiumTab: ...
    @_builtins.property
    def marketing_page_banner(self) -> Global___PremiumMarketingComponentProperties.MarketingPageBanner: ...
    @_builtins.property
    def payment_modal_banner(self) -> Global___PremiumMarketingComponentProperties.PaymentModalBanner: ...
    @_builtins.property
    def mobile_bottom_sheet(self) -> Global___PremiumMarketingComponentProperties.MobileBottomSheet: ...
    @_builtins.property
    def gift_icon(self) -> Global___PremiumMarketingComponentProperties.GiftIcon: ...
    @_builtins.property
    def gift_icon_coachmark(self) -> Global___PremiumMarketingComponentProperties.GiftIconCoachmark: ...
    @_builtins.property
    def gift_plan_selection_card_banner(self) -> Global___PremiumMarketingComponentProperties.GiftPlanSelectionCardBanner: ...
    @_builtins.property
    def gift_customization_banner(self) -> Global___PremiumMarketingComponentProperties.GiftCustomizationBanner: ...
    @_builtins.property
    def billing_settings_nitro_gift_banner(self) -> Global___PremiumMarketingComponentProperties.BillingSettingsNitroGiftBanner: ...
    @_builtins.property
    def gift_reminder_nagbar(self) -> Global___PremiumMarketingComponentProperties.GiftReminderNagbar: ...
    @_builtins.property
    def gift_reminder_coachmark(self) -> Global___PremiumMarketingComponentProperties.GiftReminderCoachmark: ...
    @_builtins.property
    def premium_tab_tooltip(self) -> Global___PremiumMarketingComponentProperties.PremiumTabTooltip: ...
    def __init__(
        self,
        *,
        content_identifier: _builtins.str = ...,
        placeholder: _builtins.str = ...,
        announcement_modal_variant_1: Global___PremiumMarketingComponentProperties.AnnouncementModalVariant1Properties | None = ...,
        premium_tab: Global___PremiumMarketingComponentProperties.PremiumTab | None = ...,
        marketing_page_banner: Global___PremiumMarketingComponentProperties.MarketingPageBanner | None = ...,
        payment_modal_banner: Global___PremiumMarketingComponentProperties.PaymentModalBanner | None = ...,
        mobile_bottom_sheet: Global___PremiumMarketingComponentProperties.MobileBottomSheet | None = ...,
        gift_icon: Global___PremiumMarketingComponentProperties.GiftIcon | None = ...,
        gift_icon_coachmark: Global___PremiumMarketingComponentProperties.GiftIconCoachmark | None = ...,
        gift_plan_selection_card_banner: Global___PremiumMarketingComponentProperties.GiftPlanSelectionCardBanner | None = ...,
        gift_customization_banner: Global___PremiumMarketingComponentProperties.GiftCustomizationBanner | None = ...,
        billing_settings_nitro_gift_banner: Global___PremiumMarketingComponentProperties.BillingSettingsNitroGiftBanner | None = ...,
        gift_reminder_nagbar: Global___PremiumMarketingComponentProperties.GiftReminderNagbar | None = ...,
        gift_reminder_coachmark: Global___PremiumMarketingComponentProperties.GiftReminderCoachmark | None = ...,
        premium_tab_tooltip: Global___PremiumMarketingComponentProperties.PremiumTabTooltip | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["announcement_modal_variant_1", b"announcement_modal_variant_1", "billing_settings_nitro_gift_banner", b"billing_settings_nitro_gift_banner", "gift_customization_banner", b"gift_customization_banner", "gift_icon", b"gift_icon", "gift_icon_coachmark", b"gift_icon_coachmark", "gift_plan_selection_card_banner", b"gift_plan_selection_card_banner", "gift_reminder_coachmark", b"gift_reminder_coachmark", "gift_reminder_nagbar", b"gift_reminder_nagbar", "marketing_page_banner", b"marketing_page_banner", "mobile_bottom_sheet", b"mobile_bottom_sheet", "payment_modal_banner", b"payment_modal_banner", "placeholder", b"placeholder", "premium_tab", b"premium_tab", "premium_tab_tooltip", b"premium_tab_tooltip", "properties", b"properties"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["announcement_modal_variant_1", b"announcement_modal_variant_1", "billing_settings_nitro_gift_banner", b"billing_settings_nitro_gift_banner", "content_identifier", b"content_identifier", "gift_customization_banner", b"gift_customization_banner", "gift_icon", b"gift_icon", "gift_icon_coachmark", b"gift_icon_coachmark", "gift_plan_selection_card_banner", b"gift_plan_selection_card_banner", "gift_reminder_coachmark", b"gift_reminder_coachmark", "gift_reminder_nagbar", b"gift_reminder_nagbar", "marketing_page_banner", b"marketing_page_banner", "mobile_bottom_sheet", b"mobile_bottom_sheet", "payment_modal_banner", b"payment_modal_banner", "placeholder", b"placeholder", "premium_tab", b"premium_tab", "premium_tab_tooltip", b"premium_tab_tooltip", "properties", b"properties"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType_properties: _TypeAlias = _typing.Literal["placeholder", "announcement_modal_variant_1", "premium_tab", "marketing_page_banner", "payment_modal_banner", "mobile_bottom_sheet", "gift_icon", "gift_icon_coachmark", "gift_plan_selection_card_banner", "gift_customization_banner", "billing_settings_nitro_gift_banner", "gift_reminder_nagbar", "gift_reminder_coachmark", "premium_tab_tooltip"]  # noqa: Y015
    _WhichOneofArgType_properties: _TypeAlias = _typing.Literal["properties", b"properties"]  # noqa: Y015
    def WhichOneof(self, oneof_group: _WhichOneofArgType_properties) -> _WhichOneofReturnType_properties | None: ...

Global___PremiumMarketingComponentProperties: _TypeAlias = PremiumMarketingComponentProperties  # noqa: Y015



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: premium_marketing/v1/PremiumMarketingComponentProperties.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'premium_marketing/v1/PremiumMarketingComponentProperties.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>premium_marketing/v1/PremiumMarketingComponentProperties.proto\x12#discord_protos.premium_marketing.v1\"\xaa=\n#PremiumMarketingComponentProperties\x12\x1a\n\x12\x63ontent_identifier\x18\x03 \x01(\t\x12\x15\n\x0bplaceholder\x18\x01 \x01(\tH\x00\x12\x94\x01\n\x1c\x61nnouncement_modal_variant_1\x18\x02 \x01(\x0b\x32l.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.AnnouncementModalVariant1PropertiesH\x00\x12j\n\x0bpremium_tab\x18\x04 \x01(\x0b\x32S.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.PremiumTabH\x00\x12}\n\x15marketing_page_banner\x18\x05 \x01(\x0b\x32\\.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.MarketingPageBannerH\x00\x12{\n\x14payment_modal_banner\x18\x06 \x01(\x0b\x32[.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.PaymentModalBannerH\x00\x12y\n\x13mobile_bottom_sheet\x18\x07 \x01(\x0b\x32Z.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.MobileBottomSheetH\x00\x12\x66\n\tgift_icon\x18\x08 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftIconH\x00\x12y\n\x13gift_icon_coachmark\x18\t \x01(\x0b\x32Z.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftIconCoachmarkH\x00\x12\x8f\x01\n\x1fgift_plan_selection_card_banner\x18\n \x01(\x0b\x32\x64.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftPlanSelectionCardBannerH\x00\x12\x85\x01\n\x19gift_customization_banner\x18\x0b \x01(\x0b\x32`.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftCustomizationBannerH\x00\x12\x95\x01\n\"billing_settings_nitro_gift_banner\x18\x0c \x01(\x0b\x32g.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.BillingSettingsNitroGiftBannerH\x00\x12{\n\x14gift_reminder_nagbar\x18\r \x01(\x0b\x32[.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftReminderNagbarH\x00\x12\x81\x01\n\x17gift_reminder_coachmark\x18\x0e \x01(\x0b\x32^.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftReminderCoachmarkH\x00\x12y\n\x13premium_tab_tooltip\x18\x0f \x01(\x0b\x32Z.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.PremiumTabTooltipH\x00\x1am\n\x0b\x46\x65\x61tureCard\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04pill\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x12\n\nimage_link\x18\x04 \x01(\t\x12\x1e\n\x16image_link_light_theme\x18\x05 \x01(\t\x1a\x90\x01\n\x12SubscriptionButton\x12\x0c\n\x04\x63opy\x18\x01 \x01(\t\x12l\n\rbutton_action\x18\x02 \x01(\x0e\x32U.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ButtonAction\x1a<\n\x08Subtitle\x12\x0c\n\x04link\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x12\n\nis_default\x18\x03 \x01(\x08\x1a\xff\x05\n\x0fVariant1Storage\x12\xb5\x01\n)hero_art_localized_video_links_dark_theme\x18\x01 \x03(\x0b\x32\x81\x01.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1Storage.HeroArtLocalizedVideoLinksDarkThemeEntry\x12\xb7\x01\n*hero_art_localized_video_links_light_theme\x18\x02 \x03(\x0b\x32\x82\x01.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1Storage.HeroArtLocalizedVideoLinksLightThemeEntry\x12\x9e\x01\n\x1dhero_art_video_subtitle_links\x18\x03 \x03(\x0b\x32w.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1Storage.HeroArtVideoSubtitleLinksEntry\x1aJ\n(HeroArtLocalizedVideoLinksDarkThemeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aK\n)HeroArtLocalizedVideoLinksLightThemeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a@\n\x1eHeroArtVideoSubtitleLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x85\x06\n#AnnouncementModalVariant1Properties\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x11\n\tsubheader\x18\x02 \x01(\t\x12\x12\n\nvideo_link\x18\x03 \x01(\t\x12\x17\n\x0fhelp_article_id\x18\x04 \x01(\t\x12k\n\rfeature_cards\x18\x05 \x03(\x0b\x32T.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.FeatureCard\x12p\n\x06\x62utton\x18\x06 \x01(\x0b\x32[.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.SubscriptionButtonH\x00\x88\x01\x01\x12\x13\n\x0b\x64ismiss_key\x18\x07 \x01(\t\x12\'\n\x1fhero_art_video_link_light_theme\x18\x08 \x01(\t\x12&\n\x1ehero_art_image_link_dark_theme\x18\t \x01(\t\x12\'\n\x1fhero_art_image_link_light_theme\x18\n \x01(\t\x12\x16\n\x0emodal_top_pill\x18\x0b \x01(\t\x12\x0c\n\x04\x62ody\x18\x0c \x01(\t\x12s\n\x18hero_art_video_subtitles\x18\r \x03(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Subtitle\x12n\n\x07storage\x18\x0e \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1StorageH\x01\x88\x01\x01\x42\t\n\x07_buttonB\n\n\x08_storage\x1a\x43\n\nPremiumTab\x12\x13\n\x0b\x62\x61\x64ge_label\x18\x01 \x01(\t\x12 \n\x18\x61\x63knowledged_badge_label\x18\x02 \x01(\t\x1a\x97\x01\n\x19MarketingPageBannerButton\x12\x0c\n\x04\x63opy\x18\x01 \x01(\t\x12l\n\rbutton_action\x18\x02 \x01(\x0e\x32U.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ButtonAction\x1a\xe3\x01\n\x13MarketingPageBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x17\n\x0fhelp_article_id\x18\x04 \x01(\t\x12w\n\x06\x62utton\x18\x05 \x01(\x0b\x32\x62.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.MarketingPageBannerButtonH\x00\x88\x01\x01\x42\t\n\x07_button\x1a\x45\n\x12PaymentModalBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x1a\x19\n\tCTAButton\x12\x0c\n\x04\x63opy\x18\x01 \x01(\t\x1a\xd1\x01\n\x11MobileBottomSheet\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x17\n\x0fhelp_article_id\x18\x04 \x01(\t\x12g\n\x06\x62utton\x18\x05 \x01(\x0b\x32R.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.CTAButtonH\x00\x88\x01\x01\x42\t\n\x07_button\x1a-\n\x08Gradient\x12\x12\n\x06\x63olors\x18\x01 \x03(\tB\x02\x10\x00\x12\r\n\x05\x61ngle\x18\x02 \x01(\x02\x1a\xdf\x01\n\x08GiftIcon\x12\x19\n\x11\x62ox_animation_url\x18\x01 \x01(\t\x12\x1d\n\x15trinket_animation_url\x18\x02 \x01(\t\x12\"\n\x1atrinket_glow_animation_url\x18\x03 \x01(\t\x12h\n\x08gradient\x18\x04 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x00\x88\x01\x01\x42\x0b\n\t_gradient\x1ai\n\x0fThemeAwareAsset\x12\x11\n\tlight_url\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61rk_url\x18\x02 \x01(\t\x12\x18\n\x10light_static_url\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x61rk_static_url\x18\x04 \x01(\t\x1a\xbc\x01\n\x11GiftIconCoachmark\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12\x11\n\tasset_url\x18\x03 \x01(\t\x12l\n\x05\x61sset\x18\x04 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x42\x08\n\x06_asset\x1a\xcf\x07\n\x1bGiftPlanSelectionCardBanner\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65sktop_body\x18\x02 \x01(\t\x12\x13\n\x0bmobile_body\x18\x03 \x01(\t\x12s\n\x0c\x61vatar_asset\x18\x04 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x12\x18\n\x10\x62\x61nner_asset_url\x18\x05 \x01(\t\x12\x1c\n\x14\x62\x61\x63kground_asset_url\x18\x06 \x01(\t\x12\x16\n\x0e\x63\x61rd_asset_url\x18\x07 \x01(\t\x12h\n\x08gradient\x18\x08 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x01\x88\x01\x01\x12s\n\x0c\x62\x61nner_asset\x18\t \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x02\x88\x01\x01\x12w\n\x10\x62\x61\x63kground_asset\x18\n \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x03\x88\x01\x01\x12q\n\ncard_asset\x18\x0b \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x04\x88\x01\x01\x12z\n\x13mobile_banner_asset\x18\x0c \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x05\x88\x01\x01\x42\x0f\n\r_avatar_assetB\x0b\n\t_gradientB\x0f\n\r_banner_assetB\x13\n\x11_background_assetB\r\n\x0b_card_assetB\x16\n\x14_mobile_banner_asset\x1a\x8e\x05\n\x17GiftCustomizationBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65sktop_body\x18\x02 \x01(\t\x12\x13\n\x0bmobile_body\x18\x03 \x01(\t\x12h\n\x08gradient\x18\x04 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x00\x88\x01\x01\x12\x1c\n\x14\x62\x61\x63kground_asset_url\x18\x05 \x01(\t\x12l\n\x05\x61sset\x18\x06 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x01\x88\x01\x01\x12w\n\x10\x62\x61\x63kground_asset\x18\x07 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x02\x88\x01\x01\x12~\n\x17mobile_background_asset\x18\x08 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x03\x88\x01\x01\x42\x0b\n\t_gradientB\x08\n\x06_assetB\x13\n\x11_background_assetB\x1a\n\x18_mobile_background_asset\x1a\x9a\x04\n\x1e\x42illingSettingsNitroGiftBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x1c\n\x14\x62\x61\x63kground_asset_url\x18\x04 \x01(\t\x12h\n\x08gradient\x18\x05 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x00\x88\x01\x01\x12\x12\n\ntext_color\x18\x06 \x01(\t\x12\x18\n\x10\x61\x64\x64itional_terms\x18\x07 \x01(\t\x12l\n\x05\x61sset\x18\x08 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x01\x88\x01\x01\x12w\n\x10\x62\x61\x63kground_asset\x18\t \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x02\x88\x01\x01\x42\x0b\n\t_gradientB\x08\n\x06_assetB\x13\n\x11_background_asset\x1a\"\n\x12GiftReminderNagbar\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x1a\xc0\x01\n\x15GiftReminderCoachmark\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12\x11\n\tasset_url\x18\x03 \x01(\t\x12l\n\x05\x61sset\x18\x04 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x42\x08\n\x06_asset\x1a\xa9\x01\n\x11PremiumTabTooltip\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12l\n\x05\x61sset\x18\x03 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x42\x08\n\x06_asset\"\xa3\x02\n\x0c\x42uttonAction\x12\x1d\n\x19\x42UTTON_ACTION_UNSPECIFIED\x10\x00\x12%\n!BUTTON_ACTION_OPEN_MARKETING_PAGE\x10\x01\x12+\n\'BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL\x10\x02\x12+\n\'BUTTON_ACTION_OPEN_TIER_1_PAYMENT_MODAL\x10\x03\x12\x46\nBBUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL_CUSTOM_CONFIRMATION_FOOTER\x10\x04\x12+\n\'BUTTON_ACTION_OPEN_PLAN_SELECTION_MODAL\x10\x05\x42\x0c\n\npropertiesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'premium_marketing.v1.PremiumMarketingComponentProperties_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._serialized_options = b'8\001'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._serialized_options = b'8\001'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._serialized_options = b'8\001'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT'].fields_by_name['colors']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT'].fields_by_name['colors']._serialized_options = b'\020\000'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES']._serialized_start=104
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES']._serialized_end=7954
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_FEATURECARD']._serialized_start=1869
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_FEATURECARD']._serialized_end=1978
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBSCRIPTIONBUTTON']._serialized_start=1981
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBSCRIPTIONBUTTON']._serialized_end=2125
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBTITLE']._serialized_start=2127
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBTITLE']._serialized_end=2187
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE']._serialized_start=2190
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE']._serialized_end=2957
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._serialized_start=2740
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._serialized_end=2814
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._serialized_start=2816
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._serialized_end=2891
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._serialized_start=2893
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._serialized_end=2957
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_ANNOUNCEMENTMODALVARIANT1PROPERTIES']._serialized_start=2960
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_ANNOUNCEMENTMODALVARIANT1PROPERTIES']._serialized_end=3733
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTAB']._serialized_start=3735
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTAB']._serialized_end=3802
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNERBUTTON']._serialized_start=3805
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNERBUTTON']._serialized_end=3956
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNER']._serialized_start=3959
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNER']._serialized_end=4186
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PAYMENTMODALBANNER']._serialized_start=4188
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PAYMENTMODALBANNER']._serialized_end=4257
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_CTABUTTON']._serialized_start=4259
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_CTABUTTON']._serialized_end=4284
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MOBILEBOTTOMSHEET']._serialized_start=4287
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MOBILEBOTTOMSHEET']._serialized_end=4496
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT']._serialized_start=4498
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT']._serialized_end=4543
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICON']._serialized_start=4546
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICON']._serialized_end=4769
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_THEMEAWAREASSET']._serialized_start=4771
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_THEMEAWAREASSET']._serialized_end=4876
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICONCOACHMARK']._serialized_start=4879
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICONCOACHMARK']._serialized_end=5067
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTPLANSELECTIONCARDBANNER']._serialized_start=5070
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTPLANSELECTIONCARDBANNER']._serialized_end=6045
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTCUSTOMIZATIONBANNER']._serialized_start=6048
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTCUSTOMIZATIONBANNER']._serialized_end=6702
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BILLINGSETTINGSNITROGIFTBANNER']._serialized_start=6705
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BILLINGSETTINGSNITROGIFTBANNER']._serialized_end=7243
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERNAGBAR']._serialized_start=7245
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERNAGBAR']._serialized_end=7279
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERCOACHMARK']._serialized_start=7282
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERCOACHMARK']._serialized_end=7474
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTABTOOLTIP']._serialized_start=7477
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTABTOOLTIP']._serialized_end=7646
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BUTTONACTION']._serialized_start=7649
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BUTTONACTION']._serialized_end=7940
# @@protoc_insertion_point(module_scope)
